#
# spec file for package kind
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kind
Version:        0.27.0
Release:        1.1
Summary:        Kubernetes IN Docker - local clusters for testing Kubernetes
License:        Apache-2.0
URL:            https://github.com/kubernetes-sigs/kind/
Source:         kind-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.17
BuildRequires:  zsh
Requires:       (docker or podman or nerdctl)

%description
kind is a tool for running local Kubernetes clusters using Docker container
"nodes". kind was primarily designed for testing Kubernetes itself, but may be
used for local development or CI.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags="-buildid= \
   -X sigs.k8s.io/kind/pkg/cmd/kind/version.gitCommit=$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo) \
   -X sigs.k8s.io/kind/pkg/cmd/kind/version.gitCommitCount=0" \
   -o bin/kind ./cmd/kind

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.27.0:
  * version v0.27.0
  * update node image with latest base image
  * bump local-path-storage to latest
  * bump kindnetd to latest
  * bump base image to latest
  * bump go to 1.23.6
  * update default node image to 1.32.2
  * enhance push-node script
  * bump base image with statically linked plugins
  * Statically link CNI plugins
  * replace dated intial design docs with a clear warning to not
    depend on implementation details
  * version test cleanup: don't mutate globals, use pre-computed
    expected values
  * Bump actions/setup-go from 5.2.0 to 5.3.0 in the actions group
  * test: upgrade nerdctl to v2
  * TEST: v1.32.1 node image
  * wait for containerd to be ready
  * retry image pulls once, fail if that doesn't work
  * doc: fix typo
  * update to latest base image with containerd 2.0.2
  * update containerd to v2.0.2
  * Bump actions/upload-artifact from 4.5.0 to 4.6.0 in the actions
    group
  * Add description to delete cluster subcommands
  * update shellescape to latest with new vanity import
  * Bump actions/upload-artifact from 4.4.3 to 4.5.0 in the actions
    group
  * update install docs for v0.26.0
  * version v0.27.0-alpha
  * fix push node having qemu setup reliably
  * fix `kind get clusters` via nerdctl
  * fix: remove NoArgs positional arguments validation
* Tue Dec 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.26.0:
  * version v0.26.0
  * Bump actions/setup-go from 5.1.0 to 5.2.0 in the actions group
  * add new push-node.sh that uses pre-compiled upstream releases
  * update default node image to 1.32 with upgraded containerd etc
  * upgrade local path images to latest
  * update local-path-provisioner with changes from v0.0.24 to
    v0.30.0 in usptream yaml, document the changes we apply
  * use latest kindnetd image build
  * fix local-path-provisioner build
  * update local-path-provisioner build to v0.30.0
  * bump base image
  * increase golangci-lint timeout 50%%
  * update go mod for tools to 1.23
  * update generated.sh for gengo changes
  * upgrade tools
  * bump base image dependencies
  * bump go to 1.23.4
  * add fallback version detection for tarballs < v1.31
  * update ingress docs
  * update install docs to v0.25.0
  * version v0.26.0-alpha
  * Add note to configuration about HA control plane
  * cleanup docs references too --loglevel
  * remove long-deprecated --loglevel flag
  * clean up kube-root references in docs
  * drop long-deprecated --kube-root flag
* Sun Nov 10 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.25.0:
  * version v0.25.0
  * bump node image
  * bump local-path-provisioner
  * bump kindnetd
  * bump base image
  * bump to go 1.22.9
  * Setting the default hostIP for `get kubeconfig`
  * remove myself from OWNERS
  * Fix site link to LoadBalancer page
  * bump go to 1.22.8
  * update container-log-max-size
  * update container-log-max-files-max-size
  * aggregate masq sync errors
  * Update site/content/docs/user/ingress.md
  * Improve the ingress controller guide
  * use agnhost for the documentation manifests
  * Bump the actions group with 2 updates
  * Update usage.yaml
  * bump kindnetd image
  * kindnet: don't collide with kube-network-policies
  * fix missing space in ip6tables error matching
  * Bump the actions group across 1 directory with 2 updates
  * CI: VM: switch away from Vagrant to Lima
  * bump default node image to kubernetes 1.31.1
  * bump kindnetd image
  * kindnetd: kube-network-policies bump to 0.6.0 to fix dns race
  * detect ip6tables setup failure and fallback to ipv4 only
  * docs: Fix quick start formatting issues
  * clarify when port-mapping is needed
  * Bump actions/upload-artifact from 4.3.6 to 4.4.0 in the actions group
  * Add install note to rootless docs
  * add loadbalancer note
  * add clarification to cri-o reference
  * Update ingress.md
  * Add CRI-O Kind tutorial to Kind user docs
  * fix getting version from tarball
  * update install docs to v0.24
  * version v0.25.0-alpha
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.24.0:
  * version v0.24.0
  * bump node image to 1.31.0
  * bump base image
  * bump kindnetd image
  * bump local path provisioner image
  * switch to go 1.22.6
  * Bump actions/upload-artifact from 4.3.5 to 4.3.6 in the actions
    group
  * Update copyright year in powershell.go
  * Add powershell completion
  * reword comments
  * Bump actions/upload-artifact from 4.3.4 to 4.3.5 in the actions
    group
  * bump kindnetd image
  * bump dependencies
  * Fix Kubeadm template format
  * Fix Ingress migration guide link error
  * Add known issue for WSL2 and cgroupv2 support
  * update rbac permissions for kindnet network policies
  * bump kindnetd image
  * implement network policies
  * use informers and context cancellation
  * kindnetd: update base image
  * Clean up known issues page
  * Mention possible pids_limit issues with rootless podman
  * Bump the actions group across 1 directory with 2 updates
  * bump node image
  * update base image
  * fix legacy env format warning
  * normalize FROM AS casing to silence buildx warnings
  * bump cni plugins to 1.5.1
  * update crictl to 1.30
  * update containerd to 1.7.18
  * update go / runc to go 1.22 / 1.1.13
  * Remove DOCKER_CLI_EXPERIMENTAL usage
  * simplify ingress guide, add Gateway API note
  * Add installation instructions for Scoop and Winget
  * switch to currently supported fedora (39)
  * Bump actions/checkout from 4.1.6 to 4.1.7 in the actions group
  * Add third party package installation note
  * e2e-k8s.sh: support --ginkgo.label-filter
  * Clean up GitHub Action definitions
  * cluster: drop DisableLocalStorageCapacityIsolation
  * switch to an active mirror
  * removed kong ingress documentation
  * Minor updates to Design docs
  * update comments regarding skipping preflight kubeadm phase
  * Add cgroupns requirement to known issues
  * update pause image to 3.10
  * Update Go dependencies
  * Add a new builder for tarballs and released artifacts
  * set skipPhases in Init and JoinConfiguration
  * Bump the actions group across 1 directory with 2 updates
  * promote stmcginnis to reviwer
  * update install docs for 0.23.0
  * version v0.24.0-alpha
  * Bump containerd to v1.7.16
  * group dependabot updates
  * make sure CI install the correct go
  * enable loading multiple image archives
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.23.0:
  This release introduces initial limited support for nerdctl and
  kube-proxy nftables mode.
  * Breaking Changes
  - The default node image is now Kubernetes 1.30.0:
    kindest/node:v1.30.0@sha256:047357ac0cfea04663786a612ba1eaba9702bef25227a794b52890dd8bcd692e
  - ipFamily config field is now validated
  - While technically a breaking change, if the value you set
    here is now caught as invalid it was being silently ignored
    and creating an ipv4 cluster previously and you should
    correct your config
  - Go 1.17+ is required for go install sigs.k8s.io/kind /
    building the kind binary
  - Prebuilt binaries are available as an alternative to go
    install
  - For local development make will automatically setup the
    correct go version
  - Note that the go team only supports 1.21+ and major linux
    distros have 1.19+
  - Future releases may increase this to a more current Go
    release
  - Future release may adopt toolchain in go.mod to make this
    seamless if you have go 1.21+ installed even without our
    makefile. We highly recommend installing go 1.21+
  * New Features
  - Initial support for nodes created with nerdctl
  - Initial support for kubeProxyMode: nftables (ahead of
    Kubernetes 1.31+, see
    https://kind.sigs.k8s.io/docs/user/configuration/#kube-proxy-mode)
  - Sweeping dependency updates, see commits for full details.
    v0.22.0...v0.23.0
* Mon Mar 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.22.0:
  * version v0.22.0
  * update to 1.29.2 image
  * bump node image
  * drop creating /kind dir at node-image build time
  * bump base image
  * allow overriding IMAGE_NAME
  * update Contour ingress docs
* Mon Mar 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kind: Kubernetes IN Docker - local clusters for
  testing Kubernetes
